@@ -147,7 +147,7 @@ Tk_ConfigureWidget(interp, tkwin, specs, argc, argv, widgRec, flags)
 	    return TCL_ERROR;
 	}
 	if (flags & TK_CONFIG_OBJS) {
-	    arg = Tcl_GetStringFromObj((Tcl_Obj *) argv[1], NULL);
+	    arg = Tcl_GetString((Tcl_Obj *) argv[1]);
 	} else {
 	    arg = argv[1];
 	}
