@@ -5,12 +5,12 @@
  *	widgets.
  *
  * Copyright (c) 1991-1994 The Regents of the University of California.
- * Copyright (c) 1994-1996 Sun Microsystems, Inc.
+ * Copyright (c) 1994-1997 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkRectOval.c,v 1.2 1998/09/14 18:23:16 stanton Exp $
+ * RCS: @(#) $Id: tkRectOval.c,v 1.3 1999/04/16 01:51:21 stanton Exp $
  */
 
 #include <stdio.h>
@@ -48,28 +48,28 @@ typedef struct RectOvalItem  {
  */
 
 static Tk_CustomOption stateOption = {
-    (Tk_OptionParseProc *) Tk_StateParseProc,
-    Tk_StatePrintProc, (ClientData) 2
+    (Tk_OptionParseProc *) TkStateParseProc,
+    TkStatePrintProc, (ClientData) 2
 };
 static Tk_CustomOption tagsOption = {
     (Tk_OptionParseProc *) Tk_CanvasTagsParseProc,
     Tk_CanvasTagsPrintProc, (ClientData) NULL
 };
 static Tk_CustomOption dashOption = {
-    (Tk_OptionParseProc *) Tk_CanvasDashParseProc,
-    Tk_CanvasDashPrintProc, (ClientData) NULL
+    (Tk_OptionParseProc *) TkCanvasDashParseProc,
+    TkCanvasDashPrintProc, (ClientData) NULL
 };
 static Tk_CustomOption tileOption = {
-    (Tk_OptionParseProc *) Tk_TileParseProc,
-    Tk_TilePrintProc, (ClientData) NULL
+    (Tk_OptionParseProc *) TkTileParseProc,
+    TkTilePrintProc, (ClientData) NULL
 };
 static Tk_CustomOption offsetOption = {
-    (Tk_OptionParseProc *) Tk_OffsetParseProc,
-    Tk_OffsetPrintProc, (ClientData) TK_OFFSET_RELATIVE
+    (Tk_OptionParseProc *) TkOffsetParseProc,
+    TkOffsetPrintProc, (ClientData) TK_OFFSET_RELATIVE
 };
 static Tk_CustomOption pixelOption = {
-    (Tk_OptionParseProc *) Tk_PixelParseProc,
-    Tk_PixelPrintProc, (ClientData) NULL
+    (Tk_OptionParseProc *) TkPixelParseProc,
+    TkPixelPrintProc, (ClientData) NULL
 };
 
 static Tk_ConfigSpec configSpecs[] = {
@@ -170,10 +170,10 @@ static void		ComputeRectOvalBbox _ANSI_ARGS_((Tk_Canvas canvas,
 			    RectOvalItem *rectOvalPtr));
 static int		ConfigureRectOval _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
-			    char **argv, int flags));
+			    Tcl_Obj *CONST argv[], int flags));
 static int		CreateRectOval _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, struct Tk_Item *itemPtr,
-			    int argc, char **argv));
+			    int argc, Tcl_Obj *CONST argv[]));
 static void		DeleteRectOval _ANSI_ARGS_((Tk_Canvas canvas,
 			    Tk_Item *itemPtr, Display *display));
 static void		DisplayRectOval _ANSI_ARGS_((Tk_Canvas canvas,
@@ -185,7 +185,7 @@ static double		OvalToPoint _ANSI_ARGS_((Tk_Canvas canvas,
 			    Tk_Item *itemPtr, double *pointPtr));
 static int		RectOvalCoords _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, Tk_Item *itemPtr, int argc,
-			    char **argv));
+			    Tcl_Obj *CONST argv[]));
 static int		RectOvalToPostscript _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, Tk_Item *itemPtr, int prepass));
 static int		RectToArea _ANSI_ARGS_((Tk_Canvas canvas,
@@ -268,7 +268,7 @@ Tk_ItemType tkOvalType = {
  * Results:
  *	A standard Tcl return value.  If an error occurred in
  *	creating the item, then an error message is left in
- *	interp->result;  in this case itemPtr is left uninitialized,
+ *	the interp's result;  in this case itemPtr is left uninitialized,
  *	so it can be safely freed by the caller.
  *
  * Side effects:
@@ -284,7 +284,7 @@ CreateRectOval(interp, canvas, itemPtr, argc, argv)
     Tk_Item *itemPtr;			/* Record to hold new item;  header
 					 * has been initialized by caller. */
     int argc;				/* Number of arguments in argv. */
-    char **argv;			/* Arguments describing rectangle. */
+    Tcl_Obj *CONST argv[];		/* Arguments describing rectangle. */
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
     int i;
@@ -293,7 +293,7 @@ CreateRectOval(interp, canvas, itemPtr, argc, argv)
     if (argc==1) {
 	i = 1;
     } else {
-	char *arg = Tcl_GetStringFromObj((Tcl_Obj *) argv[1], NULL);
+	char *arg = Tcl_GetStringFromObj(argv[1], NULL);
 	if ((argc>1) && (arg[0] == '-')
 		&& (arg[1] >= 'a') && (arg[1] <= 'z')) {
 	    i = 1;
@@ -357,7 +357,7 @@ CreateRectOval(interp, canvas, itemPtr, argc, argv)
  *	for details on what it does.
  *
  * Results:
- *	Returns TCL_OK or TCL_ERROR, and sets interp->result.
+ *	Returns TCL_OK or TCL_ERROR, and sets the interp's result.
  *
  * Side effects:
  *	The coordinates for the given item may be changed.
@@ -373,11 +373,10 @@ RectOvalCoords(interp, canvas, itemPtr, argc, argv)
 					 * read or modified. */
     int argc;				/* Number of coordinates supplied in
 					 * argv. */
-    char **argv;			/* Array of coordinates: x1, y1,
+    Tcl_Obj *CONST argv[];		/* Array of coordinates: x1, y1,
 					 * x2, y2, ... */
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
-    char c0[TCL_DOUBLE_SPACE];
 
     if (argc == 0) {
 	Tcl_Obj *obj = Tcl_NewObj();
@@ -392,31 +391,33 @@ RectOvalCoords(interp, canvas, itemPtr, argc, argv)
 	Tcl_SetObjResult(interp, obj);
     } else if ((argc == 1)||(argc == 4)) {
  	if (argc==1) {
-	    if (Tcl_ListObjGetElements(interp, (Tcl_Obj *) argv[0], &argc,
+	    if (Tcl_ListObjGetElements(interp, argv[0], &argc,
 		    (Tcl_Obj ***) &argv) != TCL_OK) {
 		return TCL_ERROR;
 	    } else if (argc != 4) {
-		sprintf(c0,"%d",argc);
-		Tcl_AppendResult(interp, "wrong # coordinates: expected 4, got ",
-		c0, (char *) NULL);
+		char buf[64 + TCL_INTEGER_SPACE];
+
+		sprintf(buf, "wrong # coordinates: expected 0 or 4, got %d", argc);
+		Tcl_SetResult(interp, buf, TCL_VOLATILE);
 		return TCL_ERROR;
 	    }
 	}
-	if ((Tk_CanvasGetCoordFromObj(interp, canvas, (Tcl_Obj *) argv[0],
+	if ((Tk_CanvasGetCoordFromObj(interp, canvas, argv[0],
  		    &rectOvalPtr->bbox[0]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, (Tcl_Obj *) argv[1],
+		|| (Tk_CanvasGetCoordFromObj(interp, canvas, argv[1],
 		    &rectOvalPtr->bbox[1]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, (Tcl_Obj *)  argv[2],
+		|| (Tk_CanvasGetCoordFromObj(interp, canvas, argv[2],
 			&rectOvalPtr->bbox[2]) != TCL_OK)
-		|| (Tk_CanvasGetCoordFromObj(interp, canvas, (Tcl_Obj *) argv[3],
+		|| (Tk_CanvasGetCoordFromObj(interp, canvas, argv[3],
 			&rectOvalPtr->bbox[3]) != TCL_OK)) {
 	    return TCL_ERROR;
 	}
 	ComputeRectOvalBbox(canvas, rectOvalPtr);
     } else {
-	sprintf(c0,"%d",argc);
-	Tcl_AppendResult(interp, "wrong # coordinates: expected 0 or 4, got ",
-	c0, (char *) NULL);
+	char buf[64 + TCL_INTEGER_SPACE];
+	
+	sprintf(buf, "wrong # coordinates: expected 0 or 4, got %d", argc);
+	Tcl_SetResult(interp, buf, TCL_VOLATILE);
 	return TCL_ERROR;
     }
     return TCL_OK;
@@ -433,7 +434,7 @@ RectOvalCoords(interp, canvas, itemPtr, argc, argv)
  *
  * Results:
  *	A standard Tcl result code.  If an error occurs, then
- *	an error message is left in interp->result.
+ *	an error message is left in the interp's result.
  *
  * Side effects:
  *	Configuration information, such as colors and stipple
@@ -448,7 +449,7 @@ ConfigureRectOval(interp, canvas, itemPtr, argc, argv, flags)
     Tk_Canvas canvas;		/* Canvas containing itemPtr. */
     Tk_Item *itemPtr;		/* Rectangle item to reconfigure. */
     int argc;			/* Number of elements in argv.  */
-    char **argv;		/* Arguments describing things to configure. */
+    Tcl_Obj *CONST argv[];	/* Arguments describing things to configure. */
     int flags;			/* Flags to pass to Tk_ConfigureWidget. */
 {
     RectOvalItem *rectOvalPtr = (RectOvalItem *) itemPtr;
@@ -465,7 +466,7 @@ ConfigureRectOval(interp, canvas, itemPtr, argc, argv, flags)
 
     tkwin = Tk_CanvasTkwin(canvas);
 
-    if (Tk_ConfigureWidget(interp, tkwin, configSpecs, argc, argv,
+    if (Tk_ConfigureWidget(interp, tkwin, configSpecs, argc, (char **) argv,
 	    (char *) rectOvalPtr, flags|TK_CONFIG_OBJS) != TCL_OK) {
 	return TCL_ERROR;
     }
@@ -730,9 +731,9 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
     }
 
     if (rectOvalPtr->outline.gc == None) {
-	bloat = 0;
+	bloat = 1;
     } else {
-	bloat = (int) (width+1)/2;
+	bloat = (width+1)/2;
     }
 
     /*
@@ -752,13 +753,13 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
 	dtmp = rectOvalPtr->bbox[0] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.x2 = tmp + bloat + 1;
+    rectOvalPtr->header.x2 = tmp + bloat;
     dtmp = rectOvalPtr->bbox[3];
     if (dtmp < (rectOvalPtr->bbox[1] + 1)) {
 	dtmp = rectOvalPtr->bbox[1] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.y2 = tmp + bloat + 1;
+    rectOvalPtr->header.y2 = tmp + bloat;
 }
 
 /*
@@ -1338,7 +1339,7 @@ TranslateRectOval(canvas, itemPtr, deltaX, deltaY)
  * Results:
  *	The return value is a standard Tcl result.  If an error
  *	occurs in generating Postscript then an error message is
- *	left in interp->result, replacing whatever used to be there.
+ *	left in the interp's result, replacing whatever used to be there.
  *	If no error occurs, then Postscript for the rectangle is
  *	appended to the result.
  *
